@@ -3,7 +3,7 @@
  * pg_checksums_ext.c
  *	  Checks, enables or disables page level checksums for a cluster
  *
- * Copyright (c) 2010-2024, PostgreSQL Global Development Group
+ * Copyright (c) 2010-2025, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
  *	  pg_checksums_ext.c
@@ -11,7 +11,7 @@
  *-------------------------------------------------------------------------
  */
 
-#define PG_CHECKSUMS_VERSION "1.2"
+#define PG_CHECKSUMS_VERSION "1.3"
 
 #include "postgres_fe.h"
 
@@ -26,7 +26,6 @@
 
 #include "catalog/pg_control.h"
 #include "common/controldata_utils.h"
-#include "common/file_perm.h"
 #include "common/file_utils.h"
 #include "common/relpath.h"
 #include "pg_getopt.h"
@@ -35,6 +34,7 @@
 #include "storage/checksum.h"
 #include "storage/checksum_impl.h"
 
+
 static int64 files_scanned = 0;
 static int64 files_written = 0;
 static int64 skippedfiles = 0;
@@ -72,11 +72,11 @@ static const char *progname;
 /*
  * Progress status information.
  */
-int64		total_size = 0;
-int64		current_size = 0;
-instr_time	last_progress_report;
-instr_time	last_throttle;
-instr_time	scan_started;
+static int64 total_size = 0;
+static int64 current_size = 0;
+static instr_time last_progress_report;
+static instr_time last_throttle;
+static instr_time scan_started;
 
 static void
 usage(void)
@@ -120,6 +120,8 @@ struct exclude_list_item
 
 /*
  * List of files excluded from checksum validation.
+ *
+ * Note: this list should be kept in sync with what basebackup.c includes.
  */
 static const struct exclude_list_item skip[] = {
 	{"pg_control", false},
@@ -137,11 +139,7 @@ update_checkpoint_lsn(void)
 {
 	bool	crc_ok;
 
-#if PG_VERSION_NUM >= 120000
 	ControlFile = get_controlfile(DataDir, &crc_ok);
-#else
-	ControlFile = get_controlfile(DataDir, progname, &crc_ok);
-#endif
 	if (!crc_ok)
 	{
 		pg_log_error("pg_control CRC value is incorrect");
@@ -664,11 +662,7 @@ scan_directory(const char *basedir, const char *subdir, bool sizeonly)
 			if (!sizeonly)
 				scan_file(fn, segmentno);
 		}
-#ifndef WIN32
 		else if (S_ISDIR(st.st_mode) || S_ISLNK(st.st_mode))
-#else
-		else if (S_ISDIR(st.st_mode) || pgwin32_is_junction(fn))
-#endif
 		{
 			/*
 			 * If going through the entries of pg_tblspc, we assume to operate
@@ -676,7 +670,7 @@ scan_directory(const char *basedir, const char *subdir, bool sizeonly)
 			 * is valid, resolving the linked locations and dive into them
 			 * directly.
 			 */
-			if (strncmp("pg_tblspc", subdir, strlen("pg_tblspc")) == 0)
+			if (strncmp(PG_TBLSPC_DIR, subdir, strlen(PG_TBLSPC_DIR)) == 0)
 			{
 				char		tblspc_path[MAXPGPATH];
 				struct stat tblspc_st;
@@ -866,11 +860,7 @@ main(int argc, char *argv[])
 	CheckDataVersion(DataDir);
 
 	/* Read the control file and check compatibility */
-#if PG_VERSION_NUM >= 120000
 	ControlFile = get_controlfile(DataDir, &crc_ok);
-#else
-	ControlFile = get_controlfile(DataDir, progname, &crc_ok);
-#endif
 	if (!crc_ok)
 	{
 		pg_log_error("pg_control CRC value is incorrect");
@@ -1025,16 +1015,16 @@ main(int argc, char *argv[])
 		if (do_sync)
 		{
 			pg_log_info("syncing data directory");
-#if PG_VERSION_NUM >= 170000
+#if PG_VERSION_NUM >= 180000
+			sync_pgdata(DataDir, PG_VERSION_NUM, sync_method, true);
+#elif PG_VERSION_NUM >= 170000
 			sync_pgdata(DataDir, PG_VERSION_NUM, sync_method);
-#elif PG_VERSION_NUM >= 120000
-			fsync_pgdata(DataDir, PG_VERSION_NUM);
 #else
-			fsync_pgdata(DataDir, progname, PG_VERSION_NUM);
+			fsync_pgdata(DataDir, PG_VERSION_NUM);
 #endif
 		}
 		pg_log_info("updating control file");
-		updateControlFile(DataDir, ControlFile, do_sync);
+		update_controlfile(DataDir, ControlFile, do_sync);
 
 		if (verbose)
 			printf(_("Data checksum version: %u\n"), ControlFile->data_checksum_version);
